@@ -5,7 +5,7 @@ use strict;
 #use warnings;
 #no warnings 'uninitialized';
 package Readonly;
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 $VERSION = eval $VERSION;
 
 # Autocroak (Thanks, MJD)
@@ -720,7 +720,7 @@ ones. For example:
 =head1 Cloning
 
 When cloning using L<Storable> or L<Clone> you will notice that the value stays
-readonly, which is correct. If you want to clone the value without copying 
+readonly, which is correct. If you want to clone the value without copying the
 readonly flag, use the C<Clone> function:
 
     Readonly::Scalar my $scalar = 'string';
@@ -728,6 +728,9 @@ readonly flag, use the C<Clone> function:
 
     $scalar_clone .= 'foo'; # no error
 
+The new variable (C<$scalar_clone>) is a mutable clone of the original
+C<$scalar>.
+
 =head1 Examples
 
 These are a few very simple examples:
